## Welcome to Use-Cases section:

### Adding Reasoning to Llama-3:

[Checkout the guide here](./adding_reasoning_to_llama_3/): teaches you how to "unlock" reasoning in Llama-3 and improving tool-calling in Llama-3 family

### Beginner guide:

[Guide link](./getting-started/) walks you through a zero to hero guide